@@ -26,12 +26,11 @@ import logging
 import os
 import shlex
 import traceback
-from functools import lru_cache
 from collections import defaultdict
 from concurrent import futures
 from contextlib import suppress
 from datetime import timedelta
-from functools import partial
+from functools import lru_cache, partial
 from uuid import UUID
 
 from docopt import DocoptExit, docopt
@@ -57,6 +56,7 @@ from bluetooth_mesh.models import (
     GenericOnOffClient,
     HealthClient,
     LightCTLClient,
+    LightExtendedControllerSetupClient,
     LightLightnessClient,
     NetworkDiagnosticClient,
     NetworkDiagnosticSetupClient,
@@ -119,6 +119,28 @@ class Command:
         return self.CMD < other.CMD
 
 
+class NodeSelectionCommandMixin:
+    USAGE = """
+    Usage:
+        %(cmd)s <uuid>...
+        %(cmd)s -g <groups>...
+
+    Options:
+        -g --groups
+    """
+
+    @staticmethod
+    def get_addresses(application, arguments):
+        uuids = arguments.get("<uuid>", [])
+        groups = arguments.get("<groups>", [])
+        return [
+            node.address
+            for node in application.network.nodes
+            if node.uuid.hex[:4] in uuids
+            or application.network.get_node_group(node) in groups
+        ]
+
+
 class LsCommand(Command):
     USAGE = """
     Usage:
@@ -210,11 +232,13 @@ class AttentionCommand(ModelCommandMixin, Command):
         return asyncio.gather(*tasks)
 
 
-class RecallSceneCommand(ModelCommandMixin, Command):
+class SceneCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
     USAGE = """
     Usage:
-        %(cmd)s [options] <uuid>...
-        %(cmd)s [options] -g <groups>...
+        %(cmd)s <uuid>...
+        %(cmd)s -g <groups>...
+        %(cmd)s -c <scene> [options] <uuid>...
+        %(cmd)s -c <scene> [options] -g <groups>...
 
     Options:
         -c --scene=SCENE    Number of scene to recall.
@@ -223,11 +247,9 @@ class RecallSceneCommand(ModelCommandMixin, Command):
     """
     ELEMENT = 0
     MODEL = SceneClient
-    CMD = "recall_scene"
-
-    async def __call__(self, application, arguments):
-        model = application.elements[0][SceneClient]
+    CMD = "scene"
 
+    async def recall(self, model, application, arguments):
         scene_number = int(arguments["--scene"])
         transition_time = int(arguments["--transition-time"])
 
@@ -255,29 +277,26 @@ class RecallSceneCommand(ModelCommandMixin, Command):
                 for name in arguments["<groups>"]
             ]
 
-        await asyncio.gather(*tasks)
+        for i in await asyncio.gather(*tasks):
+            yield i
 
+    async def get(self, model, application, arguments):
+        addresses = self.get_addresses(application, arguments)
+        results = await model.get_scene(nodes=addresses, app_index=0)
 
-class NodeSelectionCommandMixin:
-    USAGE = """
-    Usage:
-        %(cmd)s <uuid>...
-        %(cmd)s -g <groups>...
+        for address, data in results.items():
+            node = application.network.get_node(address=address)
+            group = application.network.get_node_group(node)
 
-    Options:
-        -g --groups
-    """
+            param = str(data["current_scene"]) if data is not None else None
+            yield "{} | {}: {}".format(group, node.name, param)
 
-    @staticmethod
-    def get_addresses(application, arguments):
-        uuids = arguments.get("<uuid>", [])
-        groups = arguments.get("<groups>", [])
-        return [
-            node.address
-            for node in application.network.nodes
-            if node.uuid.hex[:4] in uuids
-            or application.network.get_node_group(node) in groups
-        ]
+    async def __call__(self, application, arguments):
+        model = self.get_model(application)
+        method = self.get if arguments["--scene"] is None else self.recall
+
+        async for i in method(model, application, arguments):
+            yield i or ''
 
 
 class ModelGetCommandMixin(ModelCommandMixin, NodeSelectionCommandMixin):
@@ -966,6 +985,37 @@ class MorseCommand(ModelCommandMixin, Command):
             await set_unack(level=-32768)
 
 
+class LightExtendedControllerCommand(
+    ModelCommandMixin, NodeSelectionCommandMixin, Command
+):
+    USAGE = """
+    Usage:
+        %(cmd)s <uuid>...
+        %(cmd)s -g <groups>...
+    """
+    ELEMENT = 0
+    MODEL = LightExtendedControllerSetupClient
+    CMD = "lec"
+
+    async def __call__(self, application, arguments):
+        model = self.get_model(application)
+        addresses = self.get_addresses(application, arguments)
+
+        auto_resume = await model.get_auto_resume_mode(nodes=addresses, net_index=0)
+        auto_timer = await model.get_auto_resume_timer(nodes=addresses, net_index=0)
+
+        results = {
+            k: (auto_resume.get(k), auto_timer.get(k))
+            for k in {*auto_resume.keys(), *auto_timer.keys()}
+        }
+
+        for address, (resume, timer) in results.items():
+            node = application.network.get_node(address=address)
+            group = application.network.get_node_group(node)
+
+            yield "{} | {}: resume={}, timer={}".format(group, node.name, resume, timer)
+
+
 class HelpCommand(Command):
     CMD = "help"
 
@@ -990,6 +1040,7 @@ class PrimaryElement(Element):
         SceneClient,
         NetworkDiagnosticClient,
         NetworkDiagnosticSetupClient,
+        LightExtendedControllerSetupClient,
     ]
 
 
@@ -997,13 +1048,13 @@ application_mixins = itertools.chain(*get_plugin_manager().hook.application_mixi
 
 
 class MeshCommandLine(*application_mixins, Application):
-    PATH = "/com/silvair/meshcli/v6"
+    PATH = "/com/silvair/meshcli/v7"
 
     COMMANDS = [
         HelpCommand,
         LsCommand,
         AttentionCommand,
-        RecallSceneCommand,
+        SceneCommand,
         UptimeCommand,
         FaultCommand,
         VersionCommand,
@@ -1023,6 +1074,7 @@ class MeshCommandLine(*application_mixins, Application):
         GatewayPacketsCommand,
         AclCommand,
         PublicationCommand,
+        LightExtendedControllerCommand,
     ]
 
     COMPANY_ID = 0xFEE5
